@@ -1,7 +1,10 @@
+import json
 import re
 from marshmallow import Schema, fields, INCLUDE, post_load
 from marshmallow.utils import missing
 
+from daft_scraper import Daft
+
 
 class Seller(Schema):
     class Meta:
@@ -55,7 +58,7 @@ class ListingPoint(Schema):
         unknown = INCLUDE
 
     point_type = fields.Str(data_key="type")
-    coordinates = fields.List(fields.Int())
+    coordinates = fields.List(fields.Float())
 
 
 class ListingPRS(Schema):
@@ -64,15 +67,15 @@ class ListingPRS(Schema):
         unknown = INCLUDE
 
     totalUnitTypes = fields.Int()
-    subUnits = fields.List(fields.Nested(lambda: Listing()))
+    subUnits = fields.List(fields.Nested(lambda: ListingSchema()))
     tagLine = fields.Str()
     location = fields.Str()
     aboutDevelopment = fields.Str()
     brochure = fields.Str()
 
 
-class Listing(Schema):
-    URL_BASE = "https://daft.ie"
+class ListingSchema(Schema):
+    URL_BASE = Daft.BASE_URL
     PRICE_RE = re.compile(r'[0-9,]+')
 
     class Meta:
@@ -127,3 +130,35 @@ class Listing(Schema):
     image = fields.Dict(keys=fields.Str(), values=fields.Str())
     ber = fields.Nested(ListingBER, default=ListingBER())
     prs = fields.Nested(ListingPRS, default=ListingPRS())
+    point = fields.Nested(ListingPoint, default=ListingPoint())
+
+
+class Listing(dict):
+    _ad_page_info = None
+
+    def __init__(self, data: dict):
+        self.__dict__ = data
+
+    @property
+    def ad_page_info(self):
+        if not self._ad_page_info:
+            parsed_page = Daft().get(self.url)
+            script_text = parsed_page.find('script', {'id': '__NEXT_DATA__'})
+            self._ad_page_info = json.loads(script_text.string)
+        return self._ad_page_info
+
+    @property
+    def description(self) -> str:
+        return self.ad_page_info['props']['pageProps'].get('listing', {}).get('description', None)
+
+    @property
+    def county(self) -> list:
+        return self.ad_page_info['props']['pageProps']['dfpTargetingValues'].get('countyName', [])
+
+    @property
+    def area(self) -> list:
+        return self.ad_page_info['props']['pageProps']['dfpTargetingValues'].get('areaName', [])
+
+    @property
+    def views(self) -> int:
+        return self.ad_page_info['props']['pageProps'].get('listingViews', None)
